@@ -162,6 +162,7 @@ class EncodeFile:
         file_size: str,
         file_md5sum: str,
         step_run_id: str,
+        submitted_file_name: str,
         genome_annotation: Optional[str] = None,
         extras: Optional[Dict[str, Any]] = None,
     ) -> Dict[str, Any]:
@@ -181,6 +182,7 @@ class EncodeFile:
             "derived_from": derived_from,
             "file_size": file_size,
             "md5sum": file_md5sum,
+            "submitted_file_name": submitted_file_name,
         }
         if file_params.file_format_type:
             obj["file_format_type"] = file_params.file_format_type
